/*
 * Copyright 2011, 2012 Eric Chastain. All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are
permitted provided that the following conditions are met:

   1. Redistributions of source code must retain the above copyright notice, this list of
      conditions and the following disclaimer.

   2. Redistributions in binary form must reproduce the above copyright notice, this list
      of conditions and the following disclaimer in the documentation and/or other materials
      provided with the distribution.

THIS SOFTWARE IS PROVIDED BY ERIC CHASTAIN ''AS IS'' AND ANY EXPRESS OR IMPLIED
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL ERIC CHASTAIN OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

The views and conclusions contained in the software and documentation are those of the
authors and should not be interpreted as representing official policies, either expressed
or implied, of Eric Chastain.
*/

package me.chastain.chalkup;

import me.chastain.chalkup.R;

import android.app.ListActivity;
import android.app.AlertDialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.database.Cursor;
import android.os.Bundle;
import android.util.Log;
import android.view.ContextMenu;
import android.view.MenuItem;
import android.view.View;
import android.view.Window;
import android.view.ContextMenu.ContextMenuInfo;
import android.widget.AdapterView;
import android.widget.Button;
import android.widget.EditText;
import android.widget.ListView;
import android.widget.SimpleCursorAdapter;
import android.widget.AdapterView.AdapterContextMenuInfo;
import android.widget.AdapterView.OnItemClickListener;

public class Games extends ListActivity {

	long selectedGameId;
	String game_name;
	Cursor c;

    /** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState) {

        super.onCreate(savedInstanceState);

        this.setTitle("Games.java");
        if ( Global.showTitles == false ) { requestWindowFeature(Window.FEATURE_NO_TITLE); }

        setContentView(R.layout.games);

        fillData();

        registerForContextMenu(getListView());
        
        /*
		// Go Home by clicking the chalkup logo
		ImageView GamesBannerImageView = (ImageView)findViewById(R.id.GamesBannerImageView);
		GamesBannerImageView.setOnClickListener(new View.OnClickListener() { 
    		public void onClick(View v) { 
				Intent Home = new Intent(getBaseContext(), Main.class);
				startActivity(Home);
    		}
    	});
		*/

    	Button newGameButton = (Button) findViewById(R.id.NewGameButton); 
    	newGameButton.setOnClickListener(new View.OnClickListener() { 

    		public void onClick(View v) { 

    		// first check to see if there are any players, if not alert the user to tell them to go create some first.

    		    DB db = new DB(getApplicationContext());
    		    db.open();
    		    Cursor all_players = db.getAllPlayers();
    		    if (all_players.getCount() == 0)
    		    {
    		    	// add a dialog here to send the user over to the new player screen...
    		    	final AlertDialog.Builder alert0 = new AlertDialog.Builder(Games.this);
    		    	alert0.setTitle("No Players Found");
    		    	alert0.setMessage("There aren't any players set up, you must set up players before you can start a game.");
    		    	//alert0.setPositiveButton(arg0, arg1)
    		    	
        			alert0.setPositiveButton("New Player", new DialogInterface.OnClickListener() {
        				public void onClick(DialogInterface dialog, int whichButton) {

        	    	    	Intent new_player = new Intent(getBaseContext(), Player.class);
        	    	    	startActivity(new_player);
        					
        				}
        			});
    		    	alert0.show();
    		    }
    		    else
    		    {
    		    //// New Game Button

    			/// first get a name for the new game and pass it into participants via putExtra just like below...
    			final String default_game_name = "Game";
    			final AlertDialog.Builder alert1 = new AlertDialog.Builder(Games.this);
    			final EditText input = new EditText(Games.this);
    			input.setText(default_game_name); // Set default value for textbox.

    			alert1.setTitle("Game Name");
    			alert1.setView(input);
    			alert1.setPositiveButton("Ok", new DialogInterface.OnClickListener() {
    				public void onClick(DialogInterface dialog, int whichButton) {
    					//String value = input.getText().toString().trim();

    					//game_name = value;
    					game_name = input.getText().toString().trim();
    					
    					if (game_name.length() == 0) {
    						game_name = default_game_name;
    					}

    					// NOTE: There is a working dialog created in a function below named choosePlayersOrTeams()
    					// I'm bypassing calling that right now to make the app feature complete.
    					//choosePlayersOrTeams(game_name);
    	            	Intent participants = new Intent(getBaseContext(), GameAddParticipants.class);
    	            	participants.putExtra("game_name", game_name);
    					participants.putExtra("game_name", game_name);
    					participants.putExtra("listType", "players");
    					startActivity(participants);
    					
    				}
    			});

    			alert1.setNegativeButton("Cancel",
    					new DialogInterface.OnClickListener() {
    						public void onClick(DialogInterface dialog, int whichButton) {
    							dialog.cancel();
    						}
    					});
    			alert1.show();
    		}
    	} //
    	});

    	// Clicking an item in the list should move directly to edit.
    	ListView lv = this.getListView();

    	lv.setOnItemClickListener(new OnItemClickListener() {
    	    public void onItemClick(AdapterView<?> parent, View view, int position, long id) {

    	    	Intent game = new Intent(getBaseContext(), Game.class);
    	    	game.putExtra("_id", id);

    	    	// get game name from list text...
    	    	//game.putExtra("game_name", view.get((TextView) view).getText());

    	    	// is there a simpler way to just pull text from the list instead of having to hit the database?
    		    DB db = new DB(getApplicationContext());
    		    db.open();
    		    Cursor g = db.getGame(id);

    	    	game.putExtra("game_name", g.getString(1));

    	    	startActivity(game);

    	    }
    	  });

    }

    @Override
    public void onCreateContextMenu(ContextMenu menu, View v,ContextMenuInfo menuInfo) {
	super.onCreateContextMenu(menu, v, menuInfo);

		menu.setHeaderTitle("Game Options");
		//menu.add(1, v.getId(), 0, "Edit");
		menu.add(0, v.getId(), 0, "Delete");

		// set selectedPlayerId with the selected list items id, so we can delete later.
		AdapterContextMenuInfo info = (AdapterContextMenuInfo) menuInfo;
		selectedGameId = getListAdapter().getItemId(info.position);

	}

    // For now only allowing for the deletion of a game, if you fuck up when setting 
    // up a game you can just delete it and setup another one for now.
    @Override
	public boolean onContextItemSelected(MenuItem item) {

       	if( item.getTitle() == "Delete" ) {

		    // I hate dialogs, but lets prompt the user here anyway just to verify they did want to delete this game
			final AlertDialog.Builder confirmDeleteAlertDialog = new AlertDialog.Builder(Games.this);

			confirmDeleteAlertDialog.setTitle("Delete Game");
			confirmDeleteAlertDialog.setMessage("Are you sure you want to delete this game?");
			confirmDeleteAlertDialog.setPositiveButton("Yes", new DialogInterface.OnClickListener() {
				public void onClick(DialogInterface dialog, int whichButton) {
		       		DB db = new DB(getApplicationContext());
				    db.open();
				    db.deleteGame(selectedGameId);
				    db.close();

				    c.requery(); // refresh the list so the deleted item goes away.

				}
			});

			confirmDeleteAlertDialog.setNegativeButton("No",
					new DialogInterface.OnClickListener() {
						public void onClick(DialogInterface dialog, int whichButton) {
							dialog.cancel();
						}
					});
			confirmDeleteAlertDialog.show();

       	}
       	// else if(item.getTitle() == "Edit") {
	    	//Intent player = new Intent(getBaseContext(), Player.class);
	    	//player.putExtra("_id", selectedPlayerId);
	    	//startActivity(player);
       		//Toast.makeText(getApplicationContext(), "TODO: Edit this game.", Toast.LENGTH_SHORT).show();
       	//}
    	else {return false;}
	return true;
	}

    private void fillData() {
        //http://thinkandroid.wordpress.com/2010/01/09/simplecursoradapters-and-listviews/

    	Log.d("Games", "fillData() in Games.java. This shit is about to get real.");

        DB db = new DB(getApplicationContext());
        db.open();
        
        c = db.getAllGames();
        startManagingCursor(c);

        // the desired columns to be bound
        String[] columns = new String[] {"name", "dt"};

        // the XML defined views which the data will be bound to
        int[] to = new int[] { R.id.game_list_name, R.id.game_list_dt };

        // create the adapter using the cursor pointing to the desired data as well as the layout information
        SimpleCursorAdapter mAdapter = new SimpleCursorAdapter(this, R.layout.games_row, c, columns, to);

        // set this adapter as your ListActivity's adapter
        this.setListAdapter(mAdapter);

        // This is a bug, i get an error in logcat when trying to close this but the results are actually wrong when i dont. 
        //db.close();
    }
}
