/*
 * Copyright 2011, 2012 Eric Chastain. All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are
permitted provided that the following conditions are met:

   1. Redistributions of source code must retain the above copyright notice, this list of
      conditions and the following disclaimer.

   2. Redistributions in binary form must reproduce the above copyright notice, this list
      of conditions and the following disclaimer in the documentation and/or other materials
      provided with the distribution.

THIS SOFTWARE IS PROVIDED BY ERIC CHASTAIN ''AS IS'' AND ANY EXPRESS OR IMPLIED
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL ERIC CHASTAIN OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

The views and conclusions contained in the software and documentation are those of the
authors and should not be interpreted as representing official policies, either expressed
or implied, of Eric Chastain.
*/

package me.chastain.chalkup;

import me.chastain.chalkup.R;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuInflater;
import android.view.MenuItem;
import android.view.View;
import android.view.Window;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.ListView;
import android.widget.TextView;
import android.widget.Toast;
import android.widget.AdapterView.OnItemClickListener;

/**
 * This is the applications Main Activity, it 
 * builds, displays, and controls the home screen.
 */
public class Main extends Activity {

	String newGameName;

    @Override
    public void onCreate(Bundle savedInstanceState) {

        super.onCreate(savedInstanceState);
        
        this.setTitle("Main.java");
        if ( Global.showTitles == false ) { requestWindowFeature(Window.FEATURE_NO_TITLE); }

        setContentView(R.layout.main);

        // Load ListView and listen to clicks
        String[] options = new String[] {"Players", "Games"};

        ListView lv = (ListView)findViewById(R.id.ScoreMainListView);
        ArrayAdapter<String> myListsAdapter = new ArrayAdapter<String>(getApplicationContext(), android.R.layout.simple_list_item_1, options);
        lv.setAdapter(myListsAdapter);

        lv.setOnItemClickListener(new OnItemClickListener() {
    		public void onItemClick(AdapterView<?> parent, View view, int position, long id) {
			CharSequence selection = ((TextView) view).getText();

			if (selection.equals("Games")) {
        		Intent games = new Intent(view.getContext(), Games.class);
        		startActivity(games);
        	}
			else if (selection.equals("Players")){
		    	Intent players = new Intent(getBaseContext(), Players.class);
		    	startActivity(players);
			}
        	else {
        		Toast.makeText(getApplicationContext(), "Unrecognized Command", Toast.LENGTH_SHORT).show();
        	}	  
           }
        });
}

@Override
public boolean onCreateOptionsMenu(Menu menu) {
    MenuInflater inflater = getMenuInflater();
    inflater.inflate(R.menu.menu, menu);
    return true;
}

@Override
public boolean onOptionsItemSelected(MenuItem item) {

    switch (item.getItemId()) {
    	case R.id.menu_tellafriend_id:

    		final String mySubject = "Check out Chalk up";
    		final String myBodyText = "I've been using this program on my Android device called Chalkup to keep track of scores in games. Its open source, ask me and ill email it to you to install on your device.";
    		final Intent emailIntent = new Intent(android.content.Intent.ACTION_SEND);

    		emailIntent .setType("plain/text");
    		emailIntent .putExtra(android.content.Intent.EXTRA_EMAIL, new String[]{""});
    		emailIntent .putExtra(android.content.Intent.EXTRA_SUBJECT, mySubject);
    		emailIntent .putExtra(android.content.Intent.EXTRA_TEXT, myBodyText);
    		startActivity(Intent.createChooser(emailIntent, "Send mail..."));
    		break;

        case R.id.menu_about_id:

        	AlertDialog.Builder builder = new AlertDialog.Builder(this);
        	builder
        		.setTitle("About chalkup")
        		.setMessage(R.string.about)
        	    .setCancelable(false)
        	    .setPositiveButton("OK", new DialogInterface.OnClickListener() {
        	    	public void onClick(DialogInterface dialog, int id) {
        	    		dialog.dismiss();
        	        }
        	     });

        	AlertDialog alert = builder.create();
        	alert.show();
            break;
    }
    return true;
}

}