/*
 * Copyright 2011, 2012 Eric Chastain. All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are
permitted provided that the following conditions are met:

   1. Redistributions of source code must retain the above copyright notice, this list of
      conditions and the following disclaimer.

   2. Redistributions in binary form must reproduce the above copyright notice, this list
      of conditions and the following disclaimer in the documentation and/or other materials
      provided with the distribution.

THIS SOFTWARE IS PROVIDED BY ERIC CHASTAIN ''AS IS'' AND ANY EXPRESS OR IMPLIED
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL ERIC CHASTAIN OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

The views and conclusions contained in the software and documentation are those of the
authors and should not be interpreted as representing official policies, either expressed
or implied, of Eric Chastain.
*/

package me.chastain.chalkup;

import me.chastain.chalkup.R;

import android.app.Activity;
import android.database.Cursor;
import android.database.SQLException;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.view.Window;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Toast;

public class Player extends Activity {

	String nameChoosen;
	String playerDescription;
	long playerIdToUpdate = 0;

    /** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState) {

        super.onCreate(savedInstanceState);
        this.setTitle("Player.java");
        if ( Global.showTitles == false ) { requestWindowFeature(Window.FEATURE_NO_TITLE); }

        setContentView(R.layout.player);

    	// If we're editing load the proper values from the database.
        Bundle extras = getIntent().getExtras(); 
        if(extras != null)
        {
        	playerIdToUpdate = extras.getLong("_id");

        	// Load the data necessary to populate the form from the teams table.
            DB db = new DB(getApplicationContext());
            db.open();

            Log.d("DB", "Call to open player ID: " + Long.toString(playerIdToUpdate));

            Cursor c = db.getPlayer(playerIdToUpdate);
            c.moveToFirst();

        	// Name
        	EditText e = (EditText)findViewById(R.id.name_id);
        	e.setText(c.getString(1));

        	// Description
        	EditText d = (EditText)findViewById(R.id.player_description_id);
        	d.setText(c.getString(2));

            db.close();

        }

        // OK Button
    	Button OKButton = (Button) findViewById(R.id.player_button_ok_id); 
    	OKButton.setOnClickListener(new View.OnClickListener() { 
    		public void onClick(View view) {

    	    	// Name
    	    	EditText name = (EditText)findViewById(R.id.name_id);
    	    	nameChoosen = name.getText().toString();

    	    	EditText description = (EditText)findViewById(R.id.player_description_id);
    	    	playerDescription = description.getText().toString();

    	    	// Don't allow user to save player if no name specified.
    	    	if (nameChoosen.trim().equals("")) {
    	    		return;
    	    	}
        		DB db = new DB(view.getContext()); 

        		// add player
                long id = 0;
                boolean update_success = true;
        		try
        			{

        			db.open(); 
        			
        			if (playerIdToUpdate == 0) {
        				// Insert New
        				id = db.insertPlayer( nameChoosen, playerDescription );
        			}
        			else {
        				// Update
        				update_success = db.updatePlayer( playerIdToUpdate, nameChoosen, playerDescription );
        			}
        			db.close();
        			}
        		catch (SQLException e)
        			{
        			Toast.makeText( getApplicationContext(), e.toString(), Toast.LENGTH_LONG );
        			}

        		if (id != 0) {};
        		if (update_success != true) {};
        		finish();
    		}
    	});
    	
        // Cancel Button
    	Button CancelButton = (Button) findViewById(R.id.player_button_cancel_id); 
    	CancelButton.setOnClickListener(new View.OnClickListener() { 
    		public void onClick(View v) { 
    			finish();
    		}
    	});
    }
}
