/*
 * Copyright 2011, 2012 Eric Chastain. All rights reserved.

Redistribution and use in source and binary forms, with or without modification, are
permitted provided that the following conditions are met:

   1. Redistributions of source code must retain the above copyright notice, this list of
      conditions and the following disclaimer.

   2. Redistributions in binary form must reproduce the above copyright notice, this list
      of conditions and the following disclaimer in the documentation and/or other materials
      provided with the distribution.

THIS SOFTWARE IS PROVIDED BY ERIC CHASTAIN ''AS IS'' AND ANY EXPRESS OR IMPLIED
WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL ERIC CHASTAIN OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

The views and conclusions contained in the software and documentation are those of the
authors and should not be interpreted as representing official policies, either expressed
or implied, of Eric Chastain.
*/

package me.chastain.chalkup;

import me.chastain.chalkup.R;

import android.app.AlertDialog;
import android.app.ListActivity;
import android.content.DialogInterface;
import android.content.Intent;
import android.database.Cursor;
import android.os.Bundle;
import android.view.ContextMenu;
import android.view.MenuItem;
import android.view.View;
import android.view.Window;
import android.view.ContextMenu.ContextMenuInfo;
import android.widget.AdapterView;
import android.widget.Button;
import android.widget.ListView;
import android.widget.SimpleCursorAdapter;
import android.widget.AdapterView.AdapterContextMenuInfo;
import android.widget.AdapterView.OnItemClickListener;

public class Players extends ListActivity {

	long selectedPlayerId;

    /** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState) {

        super.onCreate( savedInstanceState );
        this.setTitle("Players.java");
        if ( Global.showTitles == false ) { requestWindowFeature(Window.FEATURE_NO_TITLE); }

        setContentView(R.layout.players);

        fillData();

        registerForContextMenu(getListView());

    	Button showButton = (Button) findViewById(R.id.players_new_player_button); 
    	showButton.setOnClickListener(new View.OnClickListener() { 
    		public void onClick(View v) { 
				Intent player = new Intent( v.getContext(), Player.class );
				startActivity(player);
    		}
    	});

    	// Clicking an item in the list should move directly to edit.
    	ListView lv = this.getListView();
    	
    	lv.setOnItemClickListener(new OnItemClickListener() {
    	    public void onItemClick(AdapterView<?> parent, View view,
    	        int position, long id) {
    	    	Intent player = new Intent(getBaseContext(), Player.class);
    	    	player.putExtra("_id", id);
    	    	startActivity(player);
    	    }
    	  });
    }

    @Override
    public void onCreateContextMenu(ContextMenu menu, View v,ContextMenuInfo menuInfo) {
	super.onCreateContextMenu(menu, v, menuInfo);

		menu.setHeaderTitle("Player Options");
		menu.add(1, v.getId(), 0, "Edit");
		menu.add(0, v.getId(), 0, "Delete");

		// set selectedPlayerId with the selected list items id, so we can delete later.
		AdapterContextMenuInfo info = (AdapterContextMenuInfo) menuInfo;
		selectedPlayerId = getListAdapter().getItemId(info.position);

	}
    
    @Override
	public boolean onContextItemSelected(MenuItem item) {
       	if(item.getTitle() == "Delete"){

		    // I hate dialogs, but lets prompt the user here anyway just to verify they did want to delete this game
			final AlertDialog.Builder confirmDeleteAlertDialog = new AlertDialog.Builder(Players.this);

			confirmDeleteAlertDialog.setTitle("Delete Player");
			confirmDeleteAlertDialog.setMessage("Are you sure you want to delete this player? If you do they will automatically be removed from any games they are players in.");
			confirmDeleteAlertDialog.setPositiveButton("Yes", new DialogInterface.OnClickListener() {
				public void onClick(DialogInterface dialog, int whichButton) {

		       		// Use DB to delete the player
		    		DB db = new DB(getApplicationContext());
		    		db.open();
		    		db.deletePlayer(selectedPlayerId);
		    		db.close();

		    		// Call fillData() again to refresh the list.
		    		fillData();
		    		// TODO: Look into just calling cursor.requery like in Games.java.
				}
			});

			confirmDeleteAlertDialog.setNegativeButton("No",
					new DialogInterface.OnClickListener() {
						public void onClick(DialogInterface dialog, int whichButton) {
							dialog.cancel();
						}
					});
			confirmDeleteAlertDialog.show();

       	}
       	else if(item.getTitle() == "Edit") {

	    	Intent player = new Intent(getBaseContext(), Player.class);
	    	player.putExtra("_id", selectedPlayerId);
	    	startActivity(player);
       	}
    	else {return false;}
	return true;
	}

    private void fillData(){
        //http://thinkandroid.wordpress.com/2010/01/09/simplecursoradapters-and-listviews/

        DB db = new DB(getApplicationContext());
        db.open();
        
        Cursor c = db.getAllPlayers();
        startManagingCursor(c);

        // the desired columns to be bound
        String[] columns = new String[] {"name", "description" };

        // the XML defined views which the data will be bound to
        int[] to = new int[] { R.id.player_list_name, R.id.player_list_description };

        // create the adapter using the cursor pointing to the desired data as well as the layout information
        SimpleCursorAdapter mAdapter = new SimpleCursorAdapter(this, R.layout.players_row, c, columns, to);

        // set this adapter as your ListActivity's adapter
        this.setListAdapter(mAdapter);

        // This is a bug, i get an error in logcat when trying to close this but the results are actually wrong when i dont. 
        //db.close();
    }
    
}
